@@ -1,11 +1,10 @@
-import datetime
 from typing import TYPE_CHECKING, List, Optional
 
 import pandas as pd
 
 from infima_client.core.types import Unset
 
-from .utils import handle_factor_date, simple_dict_to_frame
+from .utils import DateT, handle_factor_date, simple_dict_to_frame
 
 if TYPE_CHECKING:
     from infima_client.client import InfimaClient
@@ -14,11 +13,14 @@ if TYPE_CHECKING:
 def get_cohort_summary(
     *,
     client: "InfimaClient",
-    cohorts: Optional[List[str]] = None,
-    factor_date: Optional[datetime.date] = None,
+    cohorts: List[str],
+    factor_date: Optional[DateT] = None,
 ) -> Optional[pd.DataFrame]:
     resp = client.api.cohort_v1.get_cohort_summary(
-        cohorts=cohorts, factor_date=handle_factor_date(factor_date)
+        cohorts=cohorts,
+        factor_date=handle_factor_date(factor_date)
+        if factor_date is not None
+        else None,
     )
     if isinstance(resp.summary, Unset):
         return None
@@ -28,7 +30,7 @@ def get_cohort_summary(
 def get_pool_attributes(
     *,
     client: "InfimaClient",
-    cusips: Optional[List[str]] = None,
+    cusips: List[str],
 ) -> Optional[pd.DataFrame]:
     resp = client.api.pool_v1.get(
         cusips=cusips,
