@@ -19,4 +19,12 @@ def get_member_lists(
     )
     if isinstance(resp.member_lists, Unset):
         return None
-    return resp.member_lists.to_dict()
+
+    out: Dict[str, List[str]] = {}
+    for key in resp.member_lists.additional_keys:
+        cusips = resp.member_lists[key].cusips
+        if isinstance(cusips, Unset):
+            continue
+        out[key] = cusips
+
+    return out
