@@ -1,4 +1,3 @@
-import datetime
 from typing import TYPE_CHECKING, List, Optional, Union, cast
 
 import pandas as pd
@@ -9,6 +8,7 @@ if TYPE_CHECKING:
     from infima_client.client import InfimaClient
 
 from .utils import (
+    DateT,
     ResponseMapping,
     frame_chunker,
     handle_date,
@@ -21,7 +21,7 @@ def get_predictions(
     *,
     client: "InfimaClient",
     symbols: List[str],
-    as_of: Optional[datetime.date] = None,
+    as_of: Optional[DateT] = None,
     col: Optional[str] = "cpr",
     wide: bool = True,
 ) -> Optional[pd.DataFrame]:
