@@ -49,13 +49,15 @@ def handle_factor_date(dt: DateT) -> CoreFactorDate:
 
 def handle_factor_date_range(
     start: Optional[DateT], end: Optional[DateT]
-) -> CoreFactorDateRange:
+) -> Optional[CoreFactorDateRange]:
     """Convert start and end factor date objects to CoreFactorDateRange."""
-    out = CoreFactorDateRange(
-        start=handle_factor_date(start) if start is not None else UNSET,
-        end=handle_factor_date(end) if end is not None else UNSET,
-    )
-    return out
+    if start is None and end is None:
+        return None
+    else:
+        return CoreFactorDateRange(
+            start=handle_factor_date(start) if start is not None else UNSET,
+            end=handle_factor_date(end) if end is not None else UNSET,
+        )
 
 
 def maybe_parse_known_date_columns(df: pd.DataFrame) -> pd.DataFrame:
